==> musicman-0.8.6.tar.gz: musicman/musicman/kcmmusicman/mmconfig.h <==
/***************************************************************************
                          mmconfig.h  -  description
                             -------------------
    begin                : Sat Oct 4 2003
    copyright            : (C) 2003 by Avi Alkalay
    email                : avi@unix.sh
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MMCONFIG_H
#define MMCONFIG_H

#include <kcmodule.h>
#include <kaboutdata.h>

class MusicmanConfigDialog;

/**The KControl module for MusicMan configuration
  *@author Avi Alkalay
  */

class MMConfig : public KCModule  {
	Q_OBJECT
	public: 
		MMConfig(QWidget *parent = 0L, const char *name = 0L);
		~MMConfig();
		void load();
		void save();
		void defaults();
		int buttons();
		QString quickHelp() const;
		const KAboutData* aboutData();

	public slots:
		void configChanged();

	private:
		KAboutData *myAboutData;
		MusicmanConfigDialog *kcmDialog;
		KConfig * config;
	private: // Private methods
		/** Makes the dialog appear. */
		void userDialog(QWidget *parent);
};

#endif

==> musicman-0.11.tar.gz: musicman/musicman/kcmmusicman/mmconfig.h <==
/***************************************************************************
                          mmconfig.h  -  description
                             -------------------
    begin                : Sat Oct 4 2003
    copyright            : (C) 2003 by Avi Alkalay
    email                : avi@unix.sh
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MMCONFIG_H
#define MMCONFIG_H

#include <kcmodule.h>
#include <kaboutdata.h>
#include "musicmanconfig.h"


/**The KControl module for MusicMan configuration
  *@author Avi Alkalay
  */

class MMConfig : public MusicmanConfigDialog  {
	Q_OBJECT
	public: 
		MMConfig(QWidget *parent = 0L, const char *name = 0L, const QStringList dummy=0L);
		~MMConfig();
		void load();
		void save();
		void defaults();
		int buttons();
		QString quickHelp() const;
		const KAboutData* aboutData();

	public slots:
		void slotConfigChanged();
		void slotShowAbout();

	private:
		void setupUI(void);
		KAboutData *myAboutData;
		KConfig *config;
};

#endif
